@@ -1,18 +1,16 @@
-// Copyright 2013, Cong Ding. All rights reserved.
+// Copyright 2016 Cong Ding
 //
 // Licensed under the Apache License, Version 2.0 (the "License");
 // you may not use this file except in compliance with the License.
 // You may obtain a copy of the License at
 //
-//   http://www.apache.org/licenses/LICENSE-2.0
+//      http://www.apache.org/licenses/LICENSE-2.0
 //
 // Unless required by applicable law or agreed to in writing, software
 // distributed under the License is distributed on an "AS IS" BASIS,
 // WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 // See the License for the specific language governing permissions and
 // limitations under the License.
-//
-// Author: Cong Ding <dinggnu@gmail.com>
 
 package stun
 
@@ -114,7 +112,7 @@ func (c *Client) discover(conn net.PacketConn, addr *net.UDPAddr) (NATType, *Hos
 	}
 	if identical {
 		if resp == nil {
-			return NATSymmetricUDPFirewall, mappedAddr, nil
+			return SymmetricUDPFirewall, mappedAddr, nil
 		}
 		return NATNone, mappedAddr, nil
 	}
